@@ -194,6 +194,12 @@ set_VENDOR_DISTRIBUTION ()
     opensuse*)
       VENDOR_DISTRIBUTION='opensuse'
       ;;
+    alpine)
+      VENDOR_DISTRIBUTION='alpine'
+      ;;
+    nixos)
+      VENDOR_DISTRIBUTION='nixos'
+      ;;
     *)
       die "attempt to set an invalid VENDOR_DISTRIBUTION=$dist"
       ;;
@@ -252,17 +258,23 @@ set_VENDOR_RELEASE ()
       ;;
     ubuntu)
       VENDOR_RELEASE="$release"
-      if [[ "x$VENDOR_RELEASE" == 'x12.04' ]]; then
+      if [[ "z$VENDOR_RELEASE" == 'z12.04' ]]; then
         VENDOR_RELEASE="precise"
-      elif [[ "x$VENDOR_RELEASE" == 'x12.10' ]]; then
+      elif [[ "z$VENDOR_RELEASE" == 'z12.10' ]]; then
         VENDOR_RELEASE="quantal"
-      elif [[ "x$VENDOR_RELEASE" == 'x13.04' ]]; then
+      elif [[ "z$VENDOR_RELEASE" == 'z13.04' ]]; then
         VENDOR_RELEASE="raring"
       fi
       ;;
     opensuse)
       VENDOR_RELEASE="$release"
       ;;
+    alpine)
+      VENDOR_RELEASE="$release"
+      ;;
+    nixos)
+      VENDOR_RELEASE="$release"
+      ;;
     unknown)
       die "attempt to set VENDOR_RELEASE without setting VENDOR_DISTRIBUTION"
       ;;
@@ -273,13 +285,16 @@ set_VENDOR_RELEASE ()
 }
 
 
-#  Valid values are: apple, redhat, centos, canonical, oracle, suse
+#  Valid values are: alpine, apple, redhat, centos, canonical, oracle, suse
 set_VENDOR ()
 {
   local vendor
   vendor="$(echo "$1" | tr '[:upper:]' '[:lower:]')"
 
   case $vendor in
+    alpine)
+      VENDOR='alpine'
+      ;;
     apple)
       VENDOR='apple'
       ;;
@@ -307,6 +322,9 @@ set_VENDOR ()
     debian)
       VENDOR='debian'
       ;;
+    nixos)
+      VENDOR='nixos'
+      ;;
     opensuse*)
       VENDOR='suse'
       ;;
@@ -372,6 +390,10 @@ determine_target_platform ()
     # shellcheck disable=SC1091
     source '/etc/lsb-release'
     set_VENDOR 'canonical' "$DISTRIB_ID" "$DISTRIB_CODENAME"
+  elif [[ -f '/etc/alpine-release' ]]; then
+    local alpine_version
+    alpine_version="$(cat /etc/alpine-release)"
+    set_VENDOR 'alpine' 'alpine' "$alpine_version"
   fi
 
   rebuild_host_os
@@ -1781,7 +1803,7 @@ merge ()
 
     bzr push "$BRANCH"
   elif [[ -n "$VCS_CHECKOUT" ]]; then
-    die "Merge attempt occured, current VCS setup does not support this"
+    die "Merge attempt occurred, current VCS setup does not support this"
   fi
 }
 
